from ohm2_pushes_light import settings as ohm2_pushes_light_settings

ONESIGNAL_ENABLED = getattr(ohm2_pushes_light_settings, 'ONESIGNAL_ENABLED')
FIREBASE_ENABLED = getattr(ohm2_pushes_light_settings, 'FIREBASE_ENABLED')