# -*- coding: utf-8 -*-
# Generated by Django 1.11.7 on 2017-11-10 17:15
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Device',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('identity', models.CharField(max_length=2048, unique=True)),
                ('created', models.DateTimeField(default=django.utils.timezone.now)),
                ('last_update', models.DateTimeField(default=django.utils.timezone.now)),
                ('platform', models.IntegerField(choices=[(1, 'iOS'), (2, 'Android'), (3, 'Browser')])),
                ('gateway', models.IntegerField(choices=[(1, 'OneSignal'), (2, 'Firebase')], default=1)),
                ('player_id', models.CharField(max_length=2048)),
                ('push_token', models.CharField(max_length=2048)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
