# Generated by Django 2.0.1 on 2018-11-19 20:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('onesignal', '0002_auto_20180928_1418'),
    ]

    operations = [
        migrations.AlterField(
            model_name='device',
            name='identity',
            field=models.CharField(max_length=255, unique=True),
        ),
    ]
